@@ -1,17 +1,12 @@
 from .single_variable import *
 from .multi_variable import *
-from .markov_chains import MarkovChain, toMarkovChain
+from .markov_chains import MarkovChain, to_markov_chain
+from .symbolic_math import *
+from .plots import Plot_continuous
 
-import inspect
-
-from .version import *
 from datascience import *
 
 
-def ProbabilityTable():
-    return Table()
-
-
 def domain(self, *args):
     if len(args) == 1:
         return single_domain(self, args[0])
@@ -19,35 +14,31 @@ def domain(self, *args):
 
 
 def states(self, values):
-
-    return multi_domain(self, "Source", values, "Target", values)
-
-def state(self, values):
     table = self.with_column('State', values)
     table.move_to_start('State')
     return table
 
-## Binding; still in debate
-
-Table.value = domain
+# Binding
 Table.values = domain
+Table.value = domain
 Table.states = states
-Table.state = state
 Table.chart_colors = chart_colors
 Table.prob_event = prob_event
 Table.event = event
 Table.domain = domain
 Table.probability = probability
+Table.probabilities = probabilities
 Table.probability_function = probability_function
 Table.normalized = normalized
-Table.expected_value = expected_value
-Table.variance = variance
+Table.ev = ev
+Table.var = var
 Table.sd = sd
-Table.toJoint = toJoint
-Table.sample = sample
+Table.to_joint = to_joint
+Table.sample_from_dist = sample_from_dist
 Table.cdf = cdf
+Table.remove_zeros = remove_zeros
 
 # Markov Chain stuff
-Table.toMarkovChain = toMarkovChain
+Table.to_markov_chain = to_markov_chain
 Table.transition_probability = transition_probability
 Table.transition_function = transition_function
